@@ -1,5 +1,6 @@
 /*
- * (C) 2003-2014 Anope Team
+ *
+ * (C) 2003-2016 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -687,7 +688,7 @@ static void LoadVHosts()
 		NickAlias *na = NickAlias::Find(nick);
 		if (na == NULL)
 		{
-			Log() << "Removing vhost for nonexistant nick " << nick;
+			Log() << "Removing vhost for non-existent nick " << nick;
 			continue;
 		}
 
