@@ -1,13 +1,12 @@
 /* ircd-hybrid-8 protocol module
  *
- * (C) 2003-2014 Anope Team
- * (C) 2012-2015 ircd-hybrid development team
+ * (C) 2003-2016 Anope Team <team@anope.org>
+ * (C) 2012-2016 ircd-hybrid development team
  *
  * Please read COPYING and README for further details.
  *
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church.
- *
  */
 
 #include "module.h"
@@ -19,6 +18,7 @@ class HybridProto : public IRCDProto
 	BotInfo *FindIntroduced()
 	{
 		BotInfo *bi = Config->GetClient("OperServ");
+
 		if (bi && bi->introduced)
 			return bi;
 
@@ -29,10 +29,10 @@ class HybridProto : public IRCDProto
 		return NULL;
 	}
 
-	void SendSVSKillInternal(const MessageSource &source, User *user, const Anope::string &buf) anope_override
+	void SendSVSKillInternal(const MessageSource &source, User *u, const Anope::string &buf) anope_override
 	{
-		IRCDProto::SendSVSKillInternal(source, user, buf);
-		user->KillInternal(source, buf);
+		IRCDProto::SendSVSKillInternal(source, u, buf);
+		u->KillInternal(source, buf);
 	}
 
   public:
@@ -44,6 +44,7 @@ class HybridProto : public IRCDProto
 		CanSVSJoin = true;
 		CanSNLine = true;
 		CanSQLine = true;
+		CanSQLineChannel = true;
 		CanSZLine = true;
 		CanCertFP = true;
 		CanSetVHost = true;
@@ -68,7 +69,7 @@ class HybridProto : public IRCDProto
 
 	void SendSQLine(User *, const XLine *x) anope_override
 	{
-		UplinkSocket::Message(FindIntroduced()) << "ENCAP * RESV " << (x->expires ? x->expires - Anope::CurTime : 0) << " " << x->mask << " 0 :" << x->reason;
+		UplinkSocket::Message(FindIntroduced()) << "RESV * " << (x->expires ? x->expires - Anope::CurTime : 0) << " " << x->mask << " :" << x->reason;
 	}
 
 	void SendSGLineDel(const XLine *x) anope_override
@@ -78,7 +79,7 @@ class HybridProto : public IRCDProto
 
 	void SendSGLine(User *, const XLine *x) anope_override
 	{
-		UplinkSocket::Message(Config->GetClient("OperServ")) << "XLINE * " << x->mask << " 0 :" << x->GetReason();
+		UplinkSocket::Message(Config->GetClient("OperServ")) << "XLINE * " << x->mask << " " << (x->expires ? x->expires - Anope::CurTime : 0) << " :" << x->GetReason();
 	}
 
 	void SendSZLineDel(const XLine *x) anope_override
@@ -110,23 +111,21 @@ class HybridProto : public IRCDProto
 		UplinkSocket::Message(Config->GetClient("OperServ")) << "UNRESV * " << x->mask;
 	}
 
-	void SendJoin(User *user, Channel *c, const ChannelStatus *status) anope_override
+	void SendJoin(User *u, Channel *c, const ChannelStatus *status) anope_override
 	{
 		/*
-		 * Note that we must send our modes with the SJOIN and
-		 * can not add them to the mode stacker because ircd-hybrid
-		 * does not allow *any* client to op itself
+		 * Note that we must send our modes with the SJOIN and can not add them to the
+		 * mode stacker because ircd-hybrid does not allow *any* client to op itself
 		 */
-		UplinkSocket::Message() << "SJOIN " << c->creation_time << " " << c->name << " +"
-					<< c->GetModes(true, true) << " :"
-					<< (status != NULL ? status->BuildModePrefixList() : "") << user->GetUID();
+		UplinkSocket::Message() << "SJOIN " << c->creation_time << " " << c->name << " +" << c->GetModes(true, true) << " :"
+					<< (status != NULL ? status->BuildModePrefixList() : "") << u->GetUID();
 
 		/* And update our internal status for this user since this is not going through our mode handling system */
-		if (status != NULL)
+		if (status)
 		{
-			ChanUserContainer *uc = c->FindUser(user);
+			ChanUserContainer *uc = c->FindUser(u);
 
-			if (uc != NULL)
+			if (uc)
 				uc->status = *status;
 		}
 	}
@@ -185,22 +184,20 @@ class HybridProto : public IRCDProto
 		UplinkSocket::Message() << "PASS " << Config->Uplinks[Anope::CurrentUplink].password << " TS 6 :" << Me->GetSID();
 
 		/*
-		 * As of October 13, 2012, ircd-hybrid-8 does support the following capabilities
+		 * As of January 13, 2016, ircd-hybrid-8 does support the following capabilities
 		 * which are required to work with IRC-services:
 		 *
 		 * QS     - Can handle quit storm removal
 		 * EX     - Can do channel +e exemptions
-		 * CHW    - Can do channel wall @#
 		 * IE     - Can do invite exceptions
-		 * KNOCK  - Supports KNOCK
+		 * CHW    - Can do channel wall @#
 		 * TBURST - Supports topic burst
 		 * ENCAP  - Supports ENCAP
 		 * HOPS   - Supports HalfOps
 		 * SVS    - Supports services
 		 * EOB    - Supports End Of Burst message
-		 * TS6    - Capable of TS6 support
 		 */
-		UplinkSocket::Message() << "CAPAB :QS EX CHW IE ENCAP TBURST SVS HOPS EOB TS6";
+		UplinkSocket::Message() << "CAPAB :QS EX CHW IE ENCAP TBURST SVS HOPS EOB";
 
 		SendServer(Me);
 
@@ -212,7 +209,7 @@ class HybridProto : public IRCDProto
 		Anope::string modes = "+" + u->GetModes();
 
 		UplinkSocket::Message(Me) << "UID " << u->nick << " 1 " << u->timestamp << " " << modes << " "
-					 << u->GetIdent() << " " << u->host << " 0 " << u->GetUID() << " * :" << u->realname;
+					 << u->GetIdent() << " " << u->host << " 0.0.0.0 " << u->GetUID() << " * :" << u->realname;
 	}
 
 	void SendEOB() anope_override
@@ -329,6 +326,7 @@ struct IRCDMessageBMask : IRCDMessage
 		{
 			spacesepstream bans(params[3]);
 			Anope::string token;
+
 			while (bans.GetToken(token))
 				c->SetModeInternal(source, mode, token);
 		}
@@ -435,9 +433,11 @@ struct IRCDMessageSJoin : IRCDMessage
 	void Run(MessageSource &source, const std::vector<Anope::string> &params) anope_override
 	{
 		Anope::string modes;
+
 		if (params.size() >= 3)
 			for (unsigned i = 2; i < params.size() - 1; ++i)
 				modes += " " + params[i];
+
 		if (!modes.empty())
 			modes.erase(modes.begin());
 
@@ -460,7 +460,7 @@ struct IRCDMessageSJoin : IRCDMessage
 			sju.second = User::Find(buf);
 			if (!sju.second)
 			{
-				Log(LOG_DEBUG) << "SJOIN for nonexistant user " << buf << " on " << params[1];
+				Log(LOG_DEBUG) << "SJOIN for non-existent user " << buf << " on " << params[1];
 				continue;
 			}
 
@@ -485,6 +485,7 @@ struct IRCDMessageSVSMode : IRCDMessage
 	void Run(MessageSource &source, const std::vector<Anope::string> &params) anope_override
 	{
 		User *u = User::Find(params[0]);
+
 		if (!u)
 			return;
 
@@ -621,7 +622,6 @@ class ProtoHybrid : public Module
 	{
 		/* Add user modes */
 		ModeManager::AddUserMode(new UserModeOperOnly("ADMIN", 'a'));
-		ModeManager::AddUserMode(new UserMode("SOFTCALLERID", 'G'));
 		ModeManager::AddUserMode(new UserModeOperOnly("CALLERID", 'g'));
 		ModeManager::AddUserMode(new UserMode("INVIS", 'i'));
 		ModeManager::AddUserMode(new UserModeOperOnly("LOCOPS", 'l'));
@@ -631,12 +631,13 @@ class ProtoHybrid : public Module
 		ModeManager::AddUserMode(new UserModeNoone("REGISTERED", 'r'));
 		ModeManager::AddUserMode(new UserModeOperOnly("SNOMASK", 's'));
 		ModeManager::AddUserMode(new UserMode("WALLOPS", 'w'));
+		ModeManager::AddUserMode(new UserMode("CLOAK", 'x'));
 		ModeManager::AddUserMode(new UserMode("DEAF", 'D'));
+		ModeManager::AddUserMode(new UserMode("SOFTCALLERID", 'G'));
 		ModeManager::AddUserMode(new UserModeOperOnly("HIDEOPER", 'H'));
 		ModeManager::AddUserMode(new UserMode("REGPRIV", 'R'));
 		ModeManager::AddUserMode(new UserModeNoone("SSL", 'S'));
 		ModeManager::AddUserMode(new UserModeNoone("WEBIRC", 'W'));
-		ModeManager::AddUserMode(new UserMode("CLOAK", 'x'));
 
 		/* b/e/I */
 		ModeManager::AddChannelMode(new ChannelModeList("BAN", 'b'));
@@ -662,10 +663,11 @@ class ProtoHybrid : public Module
 		ModeManager::AddChannelMode(new ChannelMode("SECRET", 's'));
 		ModeManager::AddChannelMode(new ChannelMode("TOPIC", 't'));
 		ModeManager::AddChannelMode(new ChannelMode("NOCTCP", 'C'));
-		ModeManager::AddChannelMode(new ChannelModeOperOnly("OPERONLY", 'O'));
 		ModeManager::AddChannelMode(new ChannelMode("REGMODERATED", 'M'));
+		ModeManager::AddChannelMode(new ChannelModeOperOnly("OPERONLY", 'O'));
 		ModeManager::AddChannelMode(new ChannelMode("REGISTEREDONLY", 'R'));
 		ModeManager::AddChannelMode(new ChannelMode("SSL", 'S'));
+		ModeManager::AddChannelMode(new ChannelMode("NONOTICE", 'T'));
 	}
 
 public:
