@@ -1,13 +1,12 @@
 /*
  *
- * (C) 2003-2014 Anope Team
+ * (C) 2003-2016 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
  *
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church.
- *
  */
 
 #include "services.h"
@@ -73,8 +72,20 @@ void IdentifyRequest::ModuleUnload(Module *m)
 		IdentifyRequest *ir = *it;
 		++it;
 
-		ir->Release(m);
-		if (ir->owner == m)
+		ir->holds.erase(m);
+		if (ir->holds.empty() && ir->dispatched)
+		{
+			if (!ir->success)
+				ir->OnFail();
 			delete ir;
+			continue;
+		}
+
+		if (ir->owner == m)
+		{
+			if (!ir->success)
+				ir->OnFail();
+			delete ir;
+		}
 	}
 }
