@@ -1,13 +1,12 @@
 /* Channel-handling routines.
  *
- * (C) 2003-2014 Anope Team
+ * (C) 2003-2016 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
  *
  * Based on the original code of Epona by Lara.
  * Based on the original code of Services by Andy Church.
- *
  */
 
 #include "services.h"
@@ -27,6 +26,7 @@
 #include "uplink.h"
 
 channel_map ChannelList;
+std::vector<Channel *> Channel::deleting;
 
 Channel::Channel(const Anope::string &nname, time_t ts)
 {
@@ -52,6 +52,8 @@ Channel::Channel(const Anope::string &nname, time_t ts)
 
 Channel::~Channel()
 {
+	UnsetExtensibles();
+
 	FOREACH_MOD(OnChannelDelete, (this));
 
 	ModeManager::StackerDel(this);
@@ -121,7 +123,7 @@ void Channel::CheckModes()
 
 bool Channel::CheckDelete()
 {
-	/* Channel is syncing from a netburst, don't destroy it as more users are probably wanting to join immediatly
+	/* Channel is syncing from a netburst, don't destroy it as more users are probably wanting to join immediately
 	 * We also don't part the bot here either, if necessary we will part it after the sync
 	 */
 	if (this->syncing)
@@ -160,14 +162,14 @@ void Channel::DeleteUser(User *user)
 
 	ChanUserContainer *cu = user->FindChannel(this);
 	if (!this->users.erase(user))
-		Log(LOG_DEBUG) << "Channel::DeleteUser() tried to delete nonexistant user " << user->nick << " from channel " << this->name;
+		Log(LOG_DEBUG) << "Channel::DeleteUser() tried to delete non-existent user " << user->nick << " from channel " << this->name;
 
 	if (!user->chans.erase(this))
-		Log(LOG_DEBUG) << "Channel::DeleteUser() tried to delete nonexistant channel " << this->name << " from " << user->nick << "'s channel list";
+		Log(LOG_DEBUG) << "Channel::DeleteUser() tried to delete non-existent channel " << this->name << " from " << user->nick << "'s channel list";
 	delete cu;
 
-	if (this->CheckDelete())
-		delete this;
+	if (std::find(deleting.begin(), deleting.end(), this) == deleting.end())
+		deleting.push_back(this);
 }
 
 ChanUserContainer *Channel::FindUser(User *u) const
@@ -279,7 +281,7 @@ void Channel::SetModeInternal(MessageSource &setter, ChannelMode *ocm, const Ano
 
 		if (!u)
 		{
-			Log() << "MODE " << this->name << " +" << cm->mchar << " for nonexistant user " << param;
+			Log() << "MODE " << this->name << " +" << cm->mchar << " for non-existent user " << param;
 			return;
 		}
 
@@ -350,7 +352,7 @@ void Channel::RemoveModeInternal(MessageSource &setter, ChannelMode *ocm, const
 
 		if (!u)
 		{
-			Log() << "Channel::RemoveModeInternal() MODE " << this->name << "-" << cm->mchar << " for nonexistant user " << param;
+			Log() << "Channel::RemoveModeInternal() MODE " << this->name << "-" << cm->mchar << " for non-existent user " << param;
 			return;
 		}
 
@@ -656,7 +658,7 @@ void Channel::SetModesInternal(MessageSource &source, const Anope::string &mode,
 
 		if (cm->type == MODE_REGULAR)
 		{
-			/* something changed if we are adding a mode we dont have, or removing one we have */
+			/* something changed if we are adding a mode we don't have, or removing one we have */
 			changed |= !!add != this->HasMode(cm->name);
 			if (add)
 				this->SetModeInternal(source, cm, "", false);
@@ -691,7 +693,7 @@ void Channel::SetModesInternal(MessageSource &source, const Anope::string &mode,
 				this->RemoveModeInternal(source, cm, token, enforce_mlock);
 		}
 		else
-			Log() << "warning: Channel::SetModesInternal() recieved more modes requiring params than params, modes: " << mode;
+			Log() << "warning: Channel::SetModesInternal() received more modes requiring params than params, modes: " << mode;
 	}
 
 	if (!this_reference)
@@ -757,12 +759,11 @@ void Channel::KickInternal(const MessageSource &source, const Anope::string &nic
 		return;
 	}
 
-	Anope::string this_name = this->name;
 	ChannelStatus status = cu->status;
 
 	FOREACH_MOD(OnPreUserKicked, (source, cu, reason));
-	this->DeleteUser(target); /* This can delete this; */
-	FOREACH_MOD(OnUserKicked, (source, target, this_name, status, reason));
+	this->DeleteUser(target);
+	FOREACH_MOD(OnUserKicked, (source, target, this->name, status, reason));
 }
 
 bool Channel::Kick(BotInfo *bi, User *u, const char *reason, ...)
@@ -856,7 +857,8 @@ void Channel::SetCorrectModes(User *user, bool give_modes)
 				given = true;
 			}
 		}
-		else if (take_modes && !has_priv && !u_access.HasPriv(cm->name + "ME"))
+		/* modes that have no privileges assigned shouldn't be removed (like operprefix, ojoin) */
+		else if (take_modes && !has_priv && ci->GetLevel(cm->name + "ME") != ACCESS_INVALID && !u_access.HasPriv(cm->name + "ME"))
 		{
 			/* Only remove modes if they are > voice */
 			if (cm->name == "VOICE")
@@ -936,3 +938,15 @@ Channel *Channel::FindOrCreate(const Anope::string &name, bool &created, time_t
 	return chan;
 }
 
+void Channel::DeleteChannels()
+{
+	for (unsigned int i = 0; i < deleting.size(); ++i)
+	{
+		Channel *c = deleting[i];
+
+		if (c->CheckDelete())
+			delete c;
+	}
+	deleting.clear();
+}
+
