@@ -1,10 +1,9 @@
 /* Mode support
  *
- * Copyright (C) 2008-2011 Adam <Adam@anope.org>
- * Copyright (C) 2008-2014 Anope Team <team@anope.org>
+ * (C) 2008-2011 Adam <Adam@anope.org>
+ * (C) 2008-2016 Anope Team <team@anope.org>
  *
  * Please read COPYING and README for further details.
- *
  */
 
 #include "services.h"
@@ -290,7 +289,7 @@ void StackerInfo::AddMode(Mode *mode, bool set, const Anope::string &param)
 			break;
 		}
 	}
-	/* If the mode is on the other list, remove it from there (eg, we dont want +o-o Adam Adam) */
+	/* If the mode is on the other list, remove it from there (eg, we don't want +o-o Adam Adam) */
 	for (it = otherlist->begin(), it_end = otherlist->end(); it != it_end; ++it)
 	{
 		/* The param must match too (can have multiple status or list modes), but
@@ -320,7 +319,7 @@ static class ModePipe : public Pipe
 	}
 } *modePipe;
 
-/** Get the stacker info for an item, if one doesnt exist it is created
+/** Get the stacker info for an item, if one doesn't exist it is created
  * @param Item The user/channel etc
  * @return The stacker info
  */
@@ -830,8 +829,9 @@ const Anope::string Entry::GetNUHMask() const
 {
 	Anope::string n = nick.empty() ? "*" : nick,
 			u = user.empty() ? "*" : user,
-			h = host.empty() ? "*" : host;
-	return n + "!" + u + "@" + h;
+			h = host.empty() ? "*" : host,
+			r = real.empty() ? "" : "#" + real;
+	return n + "!" + u + "@" + h + r;
 }
 
 bool Entry::Matches(User *u, bool full) const
